@@ -8,19 +8,20 @@
 #' find_nearest_dose(573, increment = 50)
 #' @export
 find_nearest_dose <- function(dose = NULL, increment = 250, type = "round") {
-  if(!is.null(dose)) {
-    if(type %in% c("round", "floor", "ceiling")) {
-      if(type == "round") {
-        return(round(dose / increment) * increment)
-      }
-      if(type == "floor") {
-        return(floor(dose / increment) * increment)
-      }
-      if(type == "ceiling") {
-        return(ceiling(dose / increment) * increment)
-      }
-    }
-  } else {
+  if (is.null(dose)) {
     stop("Dose value required!")
   }
+  if (is.null(increment)) {
+    stop("increment cannot be NULL")
+  }
+  if (!type %in% c("round", "floor", "ceiling")) {
+    stop("`type` must be one of 'round', 'floor', or 'ceiling'.")
+  }
+
+  switch(
+    type,
+    round = round(dose / increment) * increment,
+    floor = floor(dose / increment) * increment,
+    ceiling = ceiling(dose / increment) * increment
+  )
 }
