@@ -15,4 +15,13 @@ test_that("calculate egfr based on cystatin works", {
       1
     ), 55.5
   )
+  expect_equal(
+    round(
+      calc_egfr_cystatin(1.3, unit_out = "mL/min/1.73m2", method = "Hoek")$value,
+      1
+    ), 57.5
+  )
+  expect_error(
+    calc_egfr_cystatin(1.3, unit_out = "ml/min", method = "hoek")
+  )
 })
